Clazz.declarePackage("J.rendersurface");
Clazz.load(["J.rendersurface.IsosurfaceRenderer"], "J.rendersurface.ContactRenderer", null, function(){
var c$ = Clazz.declareType(J.rendersurface, "ContactRenderer", J.rendersurface.IsosurfaceRenderer);
});
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
